@@ -1,6 +1,6 @@
 #include "parser.ih"
 
-spSemUnion Parser::eolnDollar()
+Pattern Parser::eolnDollar()
 {
     d_scanner.eolnDollar();
     return rawText("");
