@@ -13,7 +13,7 @@ void Scanner::maybeSwitchStream()
                     != string::npos;
 
     if (not isComment)
-        isComment = access(text.c_str(), R_OK) != 0;// the file must exist
+        isComment = fs::exists(text);               // the file must exist
                                                     // or //incl. is comment
     if (isComment)
     {
