@@ -261,6 +261,11 @@ inline void \@Base::push(std::string const &str)
     d_input.reRead(str, 0);
 }
 
+inline std::vector<\@Base::StreamStruct> const &\@Base::streamStack() const
+{
+    return d_streamStack;
+}
+
 inline void \@Base::setFilename(std::string const &name)
 {
     d_filename = name;
