@@ -2,6 +2,6 @@
 
 State::State()
 :
-    d_type(UNDETERMINED__),
+    d_type(UNDETERMINED_),
     d_rule(-1)
 {}
