@@ -2,7 +2,7 @@
 
 void States::collect(size_t idx)
 {
-    d_state[idx].setType(UNDETERMINED__);
+    d_state[idx].setType(UNDETERMINED_);
     return d_free.push_back(idx);
 }
 
